==> glpi-11.0.0.tgz: glpi/src/Glpi/Api/HL/Middleware/InternalAuthMiddleware.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2025 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

namespace Glpi\Api\HL\Middleware;

use Session;

/**
 * This middleware is not loaded by default when using the API.
 * It may be manually added on the Router instance in cases where GLPI itself needs to access the API.
 * If a user is already logged in, this middleware will allow the request to continue.
 */
class InternalAuthMiddleware extends AbstractMiddleware implements AuthMiddlewareInterface
{
    public function process(MiddlewareInput $input, callable $next): void
    {
        if (Session::getLoginUserID()) {
            $input->client = [
                'client_id' => 'internal', // Internal just means the user was authenticated internally either by cookie or an already existing session.
                'users_id'  => Session::getLoginUserID(),
                'scopes' => [],
            ];
            $input->response = null;
        } else {
            $next($input);
        }
    }
}

==> glpi-11.0.1.tgz: glpi/src/Glpi/Api/HL/Middleware/InternalAuthMiddleware.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2025 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

namespace Glpi\Api\HL\Middleware;

use Session;

/**
 * This middleware is not loaded by default when using the API.
 * It may be manually added on the Router instance in cases where GLPI itself needs to access the API.
 * If a user is already logged in, this middleware will allow the request to continue.
 */
class InternalAuthMiddleware extends AbstractMiddleware implements AuthMiddlewareInterface
{
    public function process(MiddlewareInput $input, callable $next): void
    {
        if (Session::getLoginUserID(false)) {
            $input->client = [
                'client_id' => 'internal', // Internal just means the user was authenticated internally either by cookie or an already existing session.
                'users_id'  => Session::getLoginUserID(),
                'scopes' => [],
            ];
            $input->response = null;
        } else {
            $next($input);
        }
    }
}
